@@ -3,7 +3,7 @@
 from __future__ import unicode_literals, print_function, division
 
 # Static values
-__version__  = '3.1.1'
+__version__  = '3.2.1'
 NAME         = 'xml2rfc'
 VERSION      = [ int(i) if i.isdigit() else i for i in __version__.split('.') ]
 CACHES       = ['/var/cache/xml2rfc', '~/.cache/xml2rfc']  # Ordered by priority
@@ -54,3 +54,37 @@ try:
 except (ImportError, OSError, AttributeError):
     HAVE_PANGO = False
     PANGO_VERSION = None
+
+
+def get_versions():
+    import sys
+    versions = []
+    extras = set(['pycairo', 'weasyprint'])
+    try:
+        import pkg_resources
+        this = pkg_resources.working_set.by_key[NAME]
+        for p in this.requires():
+            if p.key in extras:
+                extras -= p.key
+            try:
+                dist = pkg_resources.get_distribution(p.key)
+                versions.append((dist.project_name, dist.version))
+            except Exception as e:
+                print(e)
+                pass
+        for key in extras:
+            try:
+                dist = pkg_resources.get_distribution(key)
+                versions.append((dist.project_name, dist.version))
+            except:
+                pass
+    except:
+        pass
+
+    versions.sort(key=lambda x: x[0].lower())
+    versions = [
+            (NAME, __version__),
+            ('Python', sys.version.split()[0]),
+        ] + versions
+
+    return versions
