@@ -1971,9 +1971,16 @@ class BaseV3Writer(object):
         title = self.root.find('./front/title')
         text = title.get('abbrev') or ' '.join(title.itertext())
         if len(text) > 40:
-            self.warn(title, "Expected a title abbreviation of not more than 40 character for the page header, found %s characters" % len(text))
+            self.warn(title, "Expected a title or title abbreviation of not more than 40 character for the page header, found %s characters" % len(text))
         return text[:40]
 
+    def full_page_top_center(self):
+        title = self.root.find('./front/title')
+        text = title.get('abbrev') or ' '.join(title.itertext())
+        if len(text) > 80:
+            self.note(title, "Found a title or title abbreviation of length %s; check that it fits the running page header." % len(text))
+        return text
+
     def page_top_right(self):
         date = self.root.find('./front/date')
         year, month, day = extract_date(date, self.options.date)
@@ -2149,8 +2156,10 @@ class BaseV3Writer(object):
                     if error.message.startswith("Did not expect text"):
                         items = self.tree.xpath(error.path + '/text()')
                         for item in items:
-                            if item.strip():
-                                self.log("  Unexpected text:\n    %s" % item.strip())
+                            item = item.strip()
+                            if item:
+                                nl = '' if len(item) < 60 else '\n  '
+                                self.log('  Unexpected text:%s "%s"' % (nl, item))
 
             else:
                 log.warn('\nInvalid document: %s' % (e,))
