@@ -15,7 +15,7 @@ from lxml.etree import Element, Comment, CDATA
 import xml2rfc
 from xml2rfc import log
 from xml2rfc.util.unicode import unicode_content_tags, unicode_replacements, isascii
-from xml2rfc.utils import hastext, isempty, sdict, slugify
+from xml2rfc.utils import hastext, isempty, sdict, slugify, iscomment
 from xml2rfc.writers.base import default_options, BaseV3Writer
 
 
@@ -65,7 +65,7 @@ class V2v3XmlWriter(BaseV3Writer):
                         xi = self.element('{http://www.w3.org/2001/XInclude}include',
                                     nsmap=self.xmlrfc.nsmap,
                                     line=e.sourceline,
-                                    href="https://xml2rfc.tools.ietf.org/public/rfc/bibxml/reference.RFC.%04d.xml"%int(num))
+                                    href="https://xml2rfc.ietf.org/public/rfc/bibxml/reference.RFC.%04d.xml"%int(num))
                         xi.tail = e.tail
                         i = p.index(e)
                         p.remove(e)
@@ -80,12 +80,12 @@ class V2v3XmlWriter(BaseV3Writer):
                             xi = self.element('{http://www.w3.org/2001/XInclude}include',
                                         nsmap=self.xmlrfc.nsmap,
                                         line=e.sourceline,
-                                        href="https://xml2rfc.tools.ietf.org/public/rfc/bibxml3/reference.I-D.draft-%s.xml"%tag)
+                                        href="https://datatracker.ietf.org/doc/bibxml3/draft-%s.xml"%tag)
                         else:
                             xi = self.element('{http://www.w3.org/2001/XInclude}include',
                                         nsmap=self.xmlrfc.nsmap,
                                         line=e.sourceline,
-                                        href="https://xml2rfc.tools.ietf.org/public/rfc/bibxml3/reference.I-D.%s.xml"%tag)
+                                        href="https://datatracker.ietf.org/doc/bibxml3/draft-%s.xml"%tag)
                         xi.tail = e.tail
                         i = p.index(e)
                         p.remove(e)
@@ -93,7 +93,8 @@ class V2v3XmlWriter(BaseV3Writer):
                     else:
                         self.warn(e, 'Invalid value in %s' % lxml.etree.tostring(e))
 #        lxml.etree.cleanup_namespaces(self.root, top_nsmap=self.xmlrfc.nsmap)
-
+                else:
+                    self.note(e, "Not implemented: xi:include handling for %s:%s" % (si.get('name'), si.get('value')))
 
     def post_process_lines(self, lines):
         output = [ line.replace(u'\u00A0', ' ') for line in lines ]
@@ -165,6 +166,7 @@ class V2v3XmlWriter(BaseV3Writer):
             if self.options.verbose:
                 for comment in comments:
                     c = Comment(" v2v3: %s " % comment.strip())
+                    c.tail = ''
                     p.insert(i, c)
                     i += 1
             if not b is None:
@@ -179,11 +181,14 @@ class V2v3XmlWriter(BaseV3Writer):
                     b.append(child)         # moves child from a to b
                 p.replace(a, b)
             else:
-                if a.tail:
-                    if c is None:
-                        p.text = p.text + ' ' + a.tail if p.text else a.tail
-                    else:
-                        c.tail = a.tail
+                if iscomment(a):
+                    a.text = ''
+                for text in [a.text, a.tail]:
+                    if text:
+                        if c is None:
+                            p.text = p.text + text if p.text else text
+                        else:
+                            c.tail += text
                 p.remove(a)
         if b != None and a.sourceline:
             b.sourceline = a.sourceline
@@ -287,7 +292,8 @@ class V2v3XmlWriter(BaseV3Writer):
                                             # 2.45.3.  "docName" Attribute
                                             # 2.45.7.  "number" Attribute
                                             # 2.45.10.  "seriesNo" Attribute
-            './/seriesInfo',                # 2.47.  <seriesInfo>
+            #Disabled 
+            #'.//seriesInfo',                # 2.47.  <seriesInfo>
             './/t',                         # 2.53.  <t>
                                             # 2.53.2.  "hangText" Attribute
             './/xref',                      # 2.66.  <xref>
@@ -738,6 +744,7 @@ class V2v3XmlWriter(BaseV3Writer):
     # 
     #    This element appears as a child element of <address> (Section 2.2).
     def element_facsimile(self, e, p):
+            e.text = ''
             self.replace(e, None)
 
     # 3.3.  <format>
@@ -950,7 +957,7 @@ class V2v3XmlWriter(BaseV3Writer):
             tag = tags[style]
         else:
             self.warn(e, "Unexpected style in <spanx/>: '%s'" % style)
-            tag = None
+            tag = 'em'
         stripattr(e, ['style', '{http://www.w3.org/XML/1998/namespace}space', ])
         self.replace(e, tag, 'Replaced <spanx style="%s"/> with <%s/>' % (style, tag))
 
